<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Doctrine\ORM\EntityManager;
use Teknisa\FIS\Modules\Acessorias\Services\Fis05700GiIcmsService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis05700GiIcmsController 
{
    protected $giIcmsService;
    
    public function __construct(EntityManager $entityManager, Fis05700GiIcmsService $giIcmsService){
        $this->entityManager    = $entityManager;
        $this->giIcmsService    = $giIcmsService;
        set_time_limit(0);
    }
     
    /**
     * Função para realizar a exportação GI/ICMS
     */
    public function exportarGiIcms(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $row["NMARQUIVO"] = str_replace(' ', '', $row["NMARQUIVO"]);
            
            // Chama a função de validação
            $fileName = $this->giIcmsService->exportarGiIcms($row);
            
            // Retorna o nome do arquivo
            $response->addDataset(new DataSet('columnsToReturn', ["fileName" => $fileName]));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->giIcmsService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis05700', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $fileName = $this->giIcmsService->saveAgendamento($row);
            
            $this->entityManager->commit();

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->giIcmsService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoGiIcms(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->giIcmsService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}